@@ -1,19 +1,19 @@
 /*
-  $Id: LogStream.cxx 15058 2012-08-08 08:24:51Z sloot $
-  $URL: https://ilk.uvt.nl/svn/sources/libticclutils/trunk/src/LogStream.cxx $
+  $Id: LogStream.cxx 15267 2012-10-10 11:58:45Z sloot $
+  $URL: https://ilk.uvt.nl/svn/sources/libticcutils/trunk/src/LogStream.cxx $
 
   Copyright (c) 1998 - 2012
   ILK   - Tilburg University
   CLiPS - University of Antwerp
  
-  This file is part of timbl
+  This file is part of ticcutils
 
-  timbl is free software; you can redistribute it and/or modify
+  ticcutils is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.
 
-  timbl is distributed in the hope that it will be useful,
+  ticcutils is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
